============
boxx-pymonad
============


.. image:: https://img.shields.io/pypi/v/boxx_pymonad.svg
        :target: https://pypi.python.org/pypi/boxx_pymonad

.. image:: https://img.shields.io/travis/wboxx1/boxx-pymonad.svg
        :target: https://travis-ci.org/wboxx1/boxx-pymonad

.. image:: https://ci.appveyor.com/api/projects/status/wboxx1/branch/master?svg=true
    :target: https://ci.appveyor.com/project/wboxx1/boxx-pymonad/branch/master
    :alt: Build status on Appveyor

.. image:: https://readthedocs.org/projects/boxx-pymonad/badge/?version=latest
        :target: https://boxx-pymonad.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status




My Implementation of pymonad package.


* Free software: MIT license

* Documentation: https://wboxx1.github.io/boxx-pymonad



Installation:
-------------

.. code-block:: console

    $ pip install boxx-pymonad

Features
--------

* TODO

Credits
-------

This package was created with Cookiecutter_ and the `wboxx1/cookiecutter-pypackage-poetry`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`wboxx1/cookiecutter-pypackage-poetry`: https://github.com/wboxx1/cookiecutter-pypackage-poetry
